Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: tests/language/call_nonexistent_static_test.dart

Issue 10909166: Rename NoSuchMethodException to NoSuchMethodError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address review comments Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/language/call_nonexistent_constructor_test.dart ('k') | tests/language/implied_interface_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/language/call_nonexistent_static_test.dart
diff --git a/tests/language/call_nonexistent_static_test.dart b/tests/language/call_nonexistent_static_test.dart
index d93fad9f5532a7ba67da1c711bdda69eabacfc1c..4eb206a4d1f7b865eff404c4d5e02a0a9fdc299b 100644
--- a/tests/language/call_nonexistent_static_test.dart
+++ b/tests/language/call_nonexistent_static_test.dart
@@ -3,12 +3,12 @@
// BSD-style license that can be found in the LICENSE file.
// When attempting to call a nonexistent static method, getter or setter, check
// that a NoSuchMethodException is thrown.
class C {}
main() {
- Expect.throws(() => C.hest = 1, (e) => e is NoSuchMethodException); /// 01: static type warning
- Expect.throws(() => C.hest, (e) => e is NoSuchMethodException); /// 02: static type warning
- Expect.throws(() => C.hest(), (e) => e is NoSuchMethodException); /// 03: static type warning
+ Expect.throws(() => C.hest = 1, (e) => e is NoSuchMethodError); /// 01: static type warning
+ Expect.throws(() => C.hest, (e) => e is NoSuchMethodError); /// 02: static type warning
+ Expect.throws(() => C.hest(), (e) => e is NoSuchMethodError); /// 03: static type warning
}
« no previous file with comments | « tests/language/call_nonexistent_constructor_test.dart ('k') | tests/language/implied_interface_test.dart » ('j') | no next file with comments »
@@ -3,12 +3,12 @@
// BSD-style license that can be found in the LICENSE file.
// When attempting to call a nonexistent static method, getter or setter, check
-// that a NoSuchMethodException is thrown.
+// that a NoSuchMethodError is thrown.
class C {}
main() {

Powered by Google App Engine
This is Rietveld 408576698